@@ -2,3 +2,5 @@ from .base_model import BaseModel
 from .cached_autoregressive_model import CachedAutoregressiveModel
 from .cuda2d_model import Cuda2dModel
 from .glm_model import GLMModel
+from .encoder_decoder_model import EncoderDecoderModel
+from .t5_model import T5Model
